@@ -15,9 +15,9 @@
 import numpy as np
 import pandas as pd
 import seaborn as sns
-from quantrocket.moonshot import read_moonshot_csv, intraday_to_daily
 import matplotlib.pyplot as plt
 from matplotlib.font_manager import FontProperties
+import math
 import warnings
 import empyrical as ep
 import scipy.stats
@@ -39,6 +39,7 @@ class Tearsheet(BaseTearsheet):
     @classmethod
     def from_moonshot_csv(cls, filepath_or_buffer, figsize=None,
                           max_cols_for_details=25, trim_outliers=None,
+                          how_to_aggregate=None,
                           pdf_filename=None, riskfree=0,
                           compound=True, rolling_sharpe_window=200):
         """
@@ -62,6 +63,11 @@ class Tearsheet(BaseTearsheet):
             from the mean. Useful for dealing with data anomalies that cause
             large spikes in plots.
 
+        how_to_aggregate : dict, optional
+            a dict of {fieldname: aggregation method} specifying how to aggregate
+            fields from intraday to daily. See the docstring for
+            `moonchart.utils.intraday_to_daily` for more details.
+
         pdf_filename : string, optional
             save tear sheet to this filepath as a PDF instead of displaying
 
@@ -87,6 +93,7 @@ class Tearsheet(BaseTearsheet):
         perf = DailyPerformance.from_moonshot_csv(
             filepath_or_buffer,
             trim_outliers=trim_outliers,
+            how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
             rolling_sharpe_window=rolling_sharpe_window)
@@ -97,24 +104,10 @@ class Tearsheet(BaseTearsheet):
 
         return t.create_full_tearsheet(perf)
 
-    def _from_pnl(self, results, trim_outliers=None,
-                  riskfree=0, compound=True,
-                  rolling_sharpe_window=200):
-        """
-        Creates a full tear sheet from a pnl DataFrame.
-        """
-        performance = DailyPerformance._from_pnl(
-            results,
-            trim_outliers=trim_outliers,
-            riskfree=riskfree,
-            compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window)
-
-        return self.create_full_tearsheet(performance)
-
     @classmethod
     def from_pnl_csv(cls, filepath_or_buffer, figsize=None,
                      max_cols_for_details=25, trim_outliers=None,
+                     how_to_aggregate=None,
                      pdf_filename=None, riskfree=0,
                      compound=True, rolling_sharpe_window=200):
         """
@@ -137,6 +130,11 @@ class Tearsheet(BaseTearsheet):
             discard returns that are more than this many standard deviations
             from the mean
 
+        how_to_aggregate : dict, optional
+            a dict of {fieldname: aggregation method} specifying how to aggregate
+            fields from intraday to daily. See the docstring for
+            `moonchart.utils.intraday_to_daily` for more details.
+
         pdf_filename : string, optional
             save tear sheet to this filepath as a PDF instead of displaying
 
@@ -154,16 +152,19 @@ class Tearsheet(BaseTearsheet):
         -------
         None
         """
-        results = pd.read_csv(filepath_or_buffer,
-                              parse_dates=["Date"],
-                              index_col=["Field","Date"])
+        perf = DailyPerformance.from_pnl_csv(
+            filepath_or_buffer,
+            trim_outliers=trim_outliers,
+            how_to_aggregate=how_to_aggregate,
+            riskfree=riskfree,
+            compound=compound,
+            rolling_sharpe_window=rolling_sharpe_window)
 
         t = cls(figsize=figsize,
                 max_cols_for_details=max_cols_for_details,
                 pdf_filename=pdf_filename)
 
-        return t._from_pnl(results, trim_outliers=trim_outliers, riskfree=riskfree,
-            compound=compound, rolling_sharpe_window=rolling_sharpe_window)
+        return t.create_full_tearsheet(perf)
 
     def create_full_tearsheet(self, performance):
         """
@@ -242,13 +243,14 @@ class Tearsheet(BaseTearsheet):
 
         if agg_performance.pnl is not None:
             stats.append(["PNL", round(agg_performance.pnl.sum(), 2)])
-        if agg_performance.commissions is not None:
-            stats.append(["Commissions", round(agg_performance.commissions.sum(), 2)])
+        if agg_performance.commission_amounts is not None:
+            stats.append(["Commissions", round(agg_performance.commission_amounts.sum(), 2)])
 
         stats.append(["Start Date", agg_performance.returns.index.min().date().isoformat()])
         stats.append(["End Date", agg_performance.returns.index.max().date().isoformat()])
 
-        stats.append(['Total Months', int(len(agg_performance.returns) / 22)])
+        stats.append(['Total Months', round(
+            (agg_performance.returns.index.max() - agg_performance.returns.index.min()) / pd.Timedelta(365.25/12, 'D'))])
 
         stats.append(["", " Risk and Returns"])
         stats.append(["CAGR", "{0}%".format(round(agg_performance.cagr * 100, 1))])
@@ -281,7 +283,7 @@ class Tearsheet(BaseTearsheet):
             agg_performance.abs_exposures,
             agg_performance.net_exposures,
             agg_performance.total_holdings,
-            agg_performance.trades
+            agg_performance.turnover
             )]):
             stats.append(["", " Positions and Exposure"])
 
@@ -303,8 +305,8 @@ class Tearsheet(BaseTearsheet):
                 "Average Daily Holdings",
                 round(avg_daily_holdings)])
 
-        if agg_performance.trades is not None:
-            avg_daily_turnover = agg_performance.trades.abs().mean()
+        if agg_performance.turnover is not None:
+            avg_daily_turnover = agg_performance.turnover.mean()
             stats.append([
                 "Average Daily Turnover (percentage of capital)",
                 "{0}%".format(round(avg_daily_turnover * 100, 1))])
@@ -315,13 +317,12 @@ class Tearsheet(BaseTearsheet):
                 "Normalized CAGR (CAGR/Absolute Exposure)",
                 "{0}%".format(round(norm_cagr * 100, 1))])
 
-        with sns.axes_style("white", {'axes.linewidth': 0}):
+        with sns.axes_style("white"):
 
-            fig = plt.figure("Performance Summary")
+            fig = plt.figure("Performance Summary", figsize=(6,6))
 
             axis = fig.add_subplot(111)
-            axis.get_xaxis().set_visible(False)
-            axis.get_yaxis().set_visible(False)
+            axis.axis("off")
 
             headings, values = zip(*stats)
 
@@ -329,7 +330,7 @@ class Tearsheet(BaseTearsheet):
                 cellText=[[v] for v in values],
                 rowLabels=headings,
                 colLabels=["Performance Summary"],
-                loc="top"
+                loc="center"
             )
             for (row, col), cell in table.get_celld().items():
                 txt = cell.get_text().get_text()
@@ -338,19 +339,17 @@ class Tearsheet(BaseTearsheet):
 
             table.scale(1, 2)
             table.set_fontsize("large")
-            fig.tight_layout()
 
     def _create_constituents_tearsheet(self, performance):
         """
         Create a tear sheet of the strategies or symbols in the data.
         """
-        with sns.axes_style("white", {'axes.linewidth': 0}):
+        with sns.axes_style("white"):
 
-            fig = plt.figure("Strategies or Securities")
+            fig = plt.figure("Strategies or Securities", figsize=(6,6))
 
             axis = fig.add_subplot(111)
-            axis.get_xaxis().set_visible(False)
-            axis.get_yaxis().set_visible(False)
+            axis.axis("off")
 
             cols = list(performance.returns.columns)
             if len(cols) > 58:
@@ -359,7 +358,7 @@ class Tearsheet(BaseTearsheet):
                 cols.append("and {0} more".format(hidden_cols))
 
             cells_per_row = 4
-            cells = ["This tear sheet includes:"] + cols
+            cells = ["Included columns:"] + cols
             num_cells = len(cells)
             if num_cells > cells_per_row and num_cells % cells_per_row != 0:
                 # Cells must be divisible by cells_per_row for matplotlib table
@@ -377,7 +376,6 @@ class Tearsheet(BaseTearsheet):
 
             table.scale(2, 2)
             table.set_fontsize("large")
-            fig.tight_layout()
 
     def create_returns_tearsheet(self, performance, agg_performance=None):
         """
@@ -470,17 +468,17 @@ class Tearsheet(BaseTearsheet):
             axis = fig.add_subplot(111)
             axis.set_ylabel("PNL")
             pnl = performance.pnl.sum()
-            if performance.commissions is not None:
+            if performance.commission_amounts is not None:
                 pnl.name = "pnl"
-                commissions = performance.commissions.sum()
-                commissions.name = "commissions"
-                gross_pnl = pnl + commissions
+                commission_amounts = performance.commission_amounts.sum()
+                commission_amounts.name = "commissions"
+                gross_pnl = pnl + commission_amounts
                 gross_pnl.name = "gross pnl"
                 try:
-                    pnl = pd.concat((pnl, gross_pnl, commissions), axis=1, sort=True)
+                    pnl = pd.concat((pnl, gross_pnl, commission_amounts), axis=1, sort=True)
                 except TypeError:
                     # sort was introduced in pandas 0.23
-                    pnl = pd.concat((pnl, gross_pnl, commissions), axis=1)
+                    pnl = pd.concat((pnl, gross_pnl, commission_amounts), axis=1)
             pnl.plot(
                 ax=axis, kind="bar", title="PNL (Details)")
 
@@ -574,11 +572,11 @@ class Tearsheet(BaseTearsheet):
                 if isinstance(performance.total_holdings, pd.DataFrame):
                     self._clear_legend(plot)
 
-            if performance.trades is not None:
+            if performance.turnover is not None:
                 fig = plt.figure("Daily Turnover", figsize=figsize)
                 axis = fig.add_subplot(subplot)
                 self._y_format_as_percentage(axis)
-                turnover = performance.trades.abs()
+                turnover = performance.turnover
                 plot = turnover.plot(ax=axis, title="Daily Turnover {0}".format(extra_label))
                 axis.set_ylabel("Percentage of capital")
                 axis.set_xlabel("")
@@ -598,38 +596,54 @@ class Tearsheet(BaseTearsheet):
         if num_series > 6:
             color_palette = sns.color_palette("hls", num_series)
 
+        total_plots = sum([1 for field in (
+            performance.abs_exposures,
+            performance.net_exposures,
+            performance.total_holdings,
+            performance.turnover,
+            performance.abs_exposures) if field is not None])
+
+        rows = math.ceil(total_plots/2)
+
         with sns.color_palette(color_palette):
 
+            next_pos = 1
+
             if performance.abs_exposures is not None:
                 avg_abs_exposures = performance.abs_exposures.mean()
-                axis = fig.add_subplot(3,2,1)
+                axis = fig.add_subplot(rows,2,next_pos)
+                next_pos += 1
                 self._y_format_as_percentage(axis)
                 avg_abs_exposures.plot(ax=axis, kind="bar", title="Avg Absolute Exposure (Details)")
                 axis.set_ylabel("Percentage of capital")
 
             if performance.net_exposures is not None:
                 avg_net_exposures = performance.net_exposures.mean()
-                axis = fig.add_subplot(3,2,2)
+                axis = fig.add_subplot(rows,2,next_pos)
+                next_pos += 1
                 self._y_format_as_percentage(axis)
                 avg_net_exposures.plot(ax=axis, kind="bar", title="Avg Net Exposure (Details)")
                 axis.set_ylabel("Percentage of capital")
 
             if performance.total_holdings is not None:
                 avg_total_holdings = performance.total_holdings.mean()
-                axis = fig.add_subplot(3,2,3)
+                axis = fig.add_subplot(rows,2,next_pos)
+                next_pos += 1
                 avg_total_holdings.plot(ax=axis, kind="bar", title="Avg Daily Holdings (Details)")
                 axis.set_ylabel("Number of holdings")
 
-            if performance.trades is not None:
-                avg_daily_turnover = performance.trades.abs().mean()
-                axis = fig.add_subplot(3,2,4)
+            if performance.turnover is not None:
+                avg_daily_turnover = performance.turnover.mean()
+                axis = fig.add_subplot(rows,2,next_pos)
+                next_pos += 1
                 self._y_format_as_percentage(axis)
                 avg_daily_turnover.plot(ax=axis, kind="bar", title="Avg Daily Turnover (Details)")
                 axis.set_ylabel("Percentage of capital")
 
             if performance.abs_exposures is not None:
                 norm_cagrs = performance.cagr / avg_abs_exposures
-                axis = fig.add_subplot(3,2,5)
+                axis = fig.add_subplot(rows,2,next_pos)
+                next_pos += 1
                 self._y_format_as_percentage(axis)
                 norm_cagrs.plot(ax=axis, kind="bar", title="Normalized CAGR (CAGR/Absolute Exposure) (Details)")
                 axis.set_ylabel("Normalized CAGR")
